@@ -1,5 +1,5 @@
 // This file is part of fityk program. Copyright (C) Marcin Wojdyr
-// $Id: datatrans.cpp,v 1.7 2005/06/10 08:45:24 wojdyr Exp $
+// $Id: datatrans.cpp,v 1.8 2005/06/20 16:07:12 wojdyr Exp $
 
 // the idea of VM is based on one of boost::spirit samples - vmachine_calc
 
@@ -521,6 +521,12 @@ bool execute_code(int n, int &M, vector<double>& stack,
                 stackPtr--;
                 *stackPtr = (fabs(*stackPtr - *(stackPtr+1)) > epsilon);
                 break;
+
+                // next comparision hack, see rbool rule for more...
+            case OP_NCMP_HACK:
+                stackPtr++;                // put number, that is accidentally 
+                *stackPtr = *(stackPtr+1); // in unused part of the stack
+                break;
             
             //transformation condition 
             case OP_INDEX:
@@ -678,7 +684,12 @@ void push_double::operator()(const double& n) const
     numbers.push_back(n);
 }
 
-void push_op::push() const { code.push_back(op); }
+void push_op::push() const 
+{ 
+    code.push_back(op); 
+    if (op2)
+        code.push_back(op2); 
+}
 
 void parameterized_op::push() const
 { 
