@@ -1,5 +1,5 @@
 // This file is part of fityk program. Copyright (C) Marcin Wojdyr
-// $Id: wx_pane.h,v 1.16 2005/03/04 14:28:47 wojdyr Exp $
+// $Id: wx_pane.h,v 1.19 2005/06/03 19:29:51 wojdyr Exp $
 
 #ifndef WX_PANE__H__
 #define WX_PANE__H__
@@ -17,6 +17,7 @@ class MainPlot;
 class AuxPlot;
 class FPlot;
 class PlotCore;
+class BgManager;
 
 
 /// based on http://wiki.wxpython.org/index.cgi/ProportionalSplitterWindow
@@ -120,12 +121,13 @@ public:
     std::string zoom_backward(int n=1);
     void save_settings(wxConfigBase *cf) const;
     void read_settings(wxConfigBase *cf);
-    void refresh_plots(bool refresh, bool update);
+    void refresh_plots(bool refresh, bool update, bool only_main=false);
     void set_mouse_mode(Mouse_mode_enum m);
     void update_mouse_hints();
     bool is_background_white();
     const std::vector<std::string>& get_zoom_hist() const { return zoom_hist; }
     const MainPlot* get_plot() const { return plot; }
+    BgManager* get_bg_manager(); 
     const std::vector<FPlot*> get_visible_plots() const;
     void show_aux(int n, bool show); 
     bool aux_visible(int n) const;
@@ -133,7 +135,7 @@ public:
 
     bool crosshair_cursor;
 private:
-    Plot_shared plot_shared;
+    PlotShared plot_shared;
     MainPlot *plot;
     ProportionalSplitter *aux_split;
     AuxPlot *aux_plot[2];
@@ -190,22 +192,6 @@ private:
     const PlotPane *pane;
 };
 
-//------------------------------------------------------------------
-
-wxColour read_color_from_config(const wxConfigBase *config, const wxString& key,
-                                const wxColour& default_value);
-
-void write_color_to_config (wxConfigBase *config, const wxString& key,
-                            const wxColour& value);
-inline bool read_bool_from_config (const wxConfigBase *config, 
-                                   const wxString& key, bool def_val)
-                    { bool b; config->Read(key, &b, def_val); return b; }
-
-wxFont read_font_from_config (const wxConfigBase *config, const wxString& key,
-                              const wxFont& default_value);
-void write_font_to_config (wxConfigBase *config, const wxString& key,
-                           const wxFont& value);
-
 
 #endif //WX_PANE__H__
 
