@@ -1,5 +1,5 @@
 // This file is part of fityk program. Copyright (C) Marcin Wojdyr
-// $Id: wx_plot.cpp,v 1.26 2005/06/08 20:52:28 wojdyr Exp $
+// $Id: wx_plot.cpp,v 1.27 2005/07/08 20:06:48 wojdyr Exp $
 
 // wxwindows headers, see wxwindows samples for description
 #include <wx/wxprec.h>
@@ -471,7 +471,7 @@ void AuxPlot::OnLeftDown (wxMouseEvent &event)
 {
     cancel_mouse_left_press();
     if (event.ShiftDown()) { // the same as OnMiddleDown()
-        frame->OnGViewAll(dummy_cmd_event);
+        frame->GViewAll();
         return;
     }
     int X = event.GetPosition().x;
@@ -559,7 +559,7 @@ void AuxPlot::OnMiddleDown (wxMouseEvent& WXUNUSED(event))
 {
     if (cancel_mouse_left_press())
         return;
-    frame->OnGViewAll(dummy_cmd_event);
+    frame->GViewAll();
 }
 
 void AuxPlot::OnKeyDown (wxKeyEvent& event)
